C LAST UPDATE: 
C+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
C
C**************************
C**     LDM_GET_FIDT     **
C**************************
C
C
CD-Doc:
C FIDType          SUBROUTINE LDM_GET_FIDT (VALSTR, IVAL, IFLAG)
CD-end
      SUBROUTINE LDM_GET_FIDT (VALSTR, IVAL, IFLAG)
C
      INCLUDE 'implicit_none.finc'
C
C Purpose: Get value of string/code parameter FIDTYPE
C
C Author:  John W. Campbell, June 1993
C
C Arguments:
C
      CHARACTER*(*) VALSTR
      INTEGER IVAL
      INTEGER IFLAG

C  VALSTR    (W)   Value for the parameter as a string 'no' or 'yes'
C                  (3 characters)
C  IVAL      (W)   Code number 0=n0, 1=yes
C  IFLAG     (W)   Flag = -1 undefined value
C                       =  0 default value
C                       =  1 value set explicitly
C                       =  2 value set globally
C
C====== GLOBALS:
C
      INCLUDE 'ldm_data.finc'
      EXTERNAL LDM_BDAT
C
C====== LOCALS:
C
      CHARACTER*3 STR(2)

      DATA STR/'no','yes'/
C
C-------------------------------------------------------------------------------
C
      IVAL = FIDT
      VALSTR = STR(IVAL+1)
      IFLAG = IS_FIDT
      RETURN
      END
